/* Lopen Met IR
 *  
 * Bedien de Simple Walker II robot met een afstandsbediening. 
 * Sluit de IR-sensor op pin 2 aan en pas de IR-code's hieronder 
 * aan.
 *
 * Gemaakt: November 2016
 * Door Simon Pauw, ZB45
 * www.SimpleWalker.com
 */

/* Mapping afstandsbediening:
 *      KNOP:             CODE:    */
#define PIJL_NAAR_BOVEN   16736925
#define PIJL_NAAR_BENEDEN 16754775

/* Link de Servo- en Sonar (NewPing)-libraries.*/
#include <Servo.h>
#include <EasyIR.h>

/* Defnieer voorste servo */
#define VOOR_SERVO_NEUTRALE_STAND 90
#define VOOR_SERVO_PIN 9

/* Defnieer achterste servo */
#define ACHTER_SERVO_NEUTRALE_STAND 90
#define ACHTER_SERVO_PIN 8

/* Definieer de maximale uitslag van de servo's
   voor de loopbeweging. */
#define MAX_SERVOUITSLAG 25

/* Pauze tussen servostanen in milliseconde */
#define PAUZE 100

/* Maak servo-objecten aan */
Servo voorServo, achterServo;

/* Een variabele om de laatst ingedrukte knop van de 
 * afstandsbediening in bij te houden*/
long laatsteIRWaarde = 0;


/* Setup: wordt uitgevoerd bij het opstarten van de Simple Walker. */
void setup() {
  // Initialiseer de servo's.
  voorServo.attach(VOOR_SERVO_PIN);
  achterServo.attach(ACHTER_SERVO_PIN);

  // Zet de servo's in de neutrale positie (in het midden).
  voorServo.write(VOOR_SERVO_NEUTRALE_STAND);
  achterServo.write(ACHTER_SERVO_NEUTRALE_STAND);

  // Begin IR op pin 2
  EasyIR::init(2);

  delay(1000);
}

/* Loop: wordt herhaald tot de Simple Walker uit wordt gezet. */
void loop() {
  // lees de IR-module uit. 
  // IRWaarde = 0 -> geen knop ingedrukt
  // IRWaarde = -1 -> de laatst ingedrukte is nogsteeds ingedrukt
  long IRWaarde = EasyIR::read();
  if(IRWaarde != 0 && IRWaarde != -1) laatsteIRWaarde = IRWaarde;
  
  // Voor looppatroon uit.
  if (laatsteIRWaarde == PIJL_NAAR_BOVEN)
  {
    // Als de laatst ingedrukte knop een pijltje naar boven is
    // loop dan vooruit.
    voorServo.write(VOOR_SERVO_NEUTRALE_STAND + MAX_SERVOUITSLAG);
    delay(PAUZE);
    achterServo.write( ACHTER_SERVO_NEUTRALE_STAND  - MAX_SERVOUITSLAG);
    delay(PAUZE);
    voorServo.write(VOOR_SERVO_NEUTRALE_STAND - MAX_SERVOUITSLAG);
    delay(PAUZE);
    achterServo.write( ACHTER_SERVO_NEUTRALE_STAND  + MAX_SERVOUITSLAG);
    delay(PAUZE);
  } else if (laatsteIRWaarde == PIJL_NAAR_BENEDEN)
  {
    // Als de laatst ingedrukte knop een pijltje naar beneden is
    // loop dan achteruit.    
    voorServo.write(VOOR_SERVO_NEUTRALE_STAND - MAX_SERVOUITSLAG);
    delay(PAUZE);
    achterServo.write(ACHTER_SERVO_NEUTRALE_STAND  - MAX_SERVOUITSLAG);
    delay(PAUZE);
    voorServo.write(VOOR_SERVO_NEUTRALE_STAND + MAX_SERVOUITSLAG);
    delay(PAUZE);
    achterServo.write(ACHTER_SERVO_NEUTRALE_STAND  + MAX_SERVOUITSLAG);
    delay(PAUZE);
  } 
}


